@@ -32,12 +32,12 @@ if (!isGeneric("dimensions"))
 if (!isGeneric("geometry"))
 	setGeneric("geometry", function(obj)
 		standardGeneric("geometry"))
-if (!isGeneric("gridded"))
-	setGeneric("gridded", function(obj)
-		standardGeneric("gridded"))
-if (!isGeneric("is.projected"))
-	setGeneric("is.projected", function(obj)
-		standardGeneric("is.projected"))
+#if (!isGeneric("gridded"))
+#	setGeneric("gridded", function(obj)
+#		standardGeneric("gridded"))
+#if (!isGeneric("is.projected"))
+#	setGeneric("is.projected", function(obj)
+#		standardGeneric("is.projected"))
 if (!isGeneric("overlay"))
 	setGeneric("overlay", function(x, y, ...)
 		standardGeneric("overlay"))
@@ -53,12 +53,12 @@ if (!isGeneric("polygons"))
 if (!isGeneric("polygons<-"))
 	setGeneric("polygons<-", function(object, value)
 		standardGeneric("polygons<-"))
-if (!isGeneric("proj4string"))
-	setGeneric("proj4string", function(obj)
-		standardGeneric("proj4string"))
-if (!isGeneric("proj4string<-"))
-	setGeneric("proj4string<-", function(obj, value)
-		standardGeneric("proj4string<-"))
+#if (!isGeneric("proj4string"))
+#	setGeneric("proj4string", function(obj)
+#		standardGeneric("proj4string"))
+#if (!isGeneric("proj4string<-"))
+#	setGeneric("proj4string<-", function(obj, value)
+#		standardGeneric("proj4string<-"))
 if (!isGeneric("spplot"))
 	setGeneric("spplot", function(obj, ...)
 		standardGeneric("spplot"))
